``cocotb``
==========

One of the main benefits of integrating well supported open-source EDA
design tools is the potential tools integration options this enables.

``cocotb`` is closely integrated with many HDL and Verilog-A simulators,
which allows ``piel`` to directly create a link between these tools and
``GDSFactory`` and related photonic design tools. Some simulators that
can be integrated accordingly are:

-  `Cadence
   Xcelium <https://www.cadence.com/en_US/home/tools/system-design-and-verification/simulation-and-testbench-verification/xcelium-simulator.html>`__
   and `Verilog-A <https://en.wikipedia.org/wiki/Verilog-A>`__ via
   `cocotb simulator
   support <https://docs.cocotb.org/en/stable/simulator_support.html#sim-xcelium>`__.
-  `ModelSim <https://docs.cocotb.org/en/stable/simulator_support.html>`__
-  `QuestaSim <https://docs.cocotb.org/en/stable/simulator_support.html>`__
-  `GHDL <https://docs.cocotb.org/en/stable/simulator_support.html>`__

.. toctree::

    cocotb_useful_commands
    ../../../autoapi/piel/tools/cocotb/index.rst
